@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hlint
-version: 1.9.31
-id: hlint-1.9.31-5b1114a706a8c17e6d849e35c0f4cbd6
-key: hlint_D7ILj3IWkmlLNpBEiawC66
+version: 1.9.32
+id: hlint-1.9.32-90db989eb30a130842bd3014d63efdf6
+key: hlint_8xWLgFPgd4c16qowRhXdfy
 license: BSD3
 copyright: Neil Mitchell 2006-2016
 maintainer: Neil Mitchell <ndmitchell@gmail.com>
@@ -26,10 +26,10 @@ hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                 Hint.Unsafe Hint.Util Test.All Test.Annotations Test.InputOutput
                 Test.Proof Test.Translate Test.Util
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.31
-library-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.31
+import-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.32
+library-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.32
 data-dir: /usr/share/hlint
-hs-libraries: HShlint-1.9.31-D7ILj3IWkmlLNpBEiawC66
+hs-libraries: HShlint-1.9.32-8xWLgFPgd4c16qowRhXdfy
 depends:
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
